import 'package:flutter/material.dart';
import 'dart:async';
import 'package:shared_preferences/shared_preferences.dart';

import '../../config.dart';
import '../app.dart';

class Home extends StatefulWidget {
  Home({
    @required this.mode,
    @required this.host,
    @required this.setHost,
    @required this.authorizeClick,
    @required this.openDashboardClick,
    @required this.buttonsHidden,
  });

  final AppMode mode;
  final String host;
  final bool buttonsHidden;
  final void Function(String) setHost;
  final void Function() openDashboardClick;
  final void Function() authorizeClick;

  @override
  _HomeState createState() => _HomeState();
}

class _HomeState extends State<Home> {
  @override
  initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    if (widget.buttonsHidden) {
      return Scaffold();
    }

    var children = <Widget>[
      _urlButton(context, "Open Dashboard", widget.openDashboardClick),
    ];

    if (widget.mode == AppMode.Authorization) {
      children.add(_urlButton(context, "Authorize with Vereign", widget.authorizeClick));
    }

    if (Config.appFlavor == Flavor.DEVELOPMENT) {
      children.add(
        wrapInContainer(
          DropdownButton<String>(
            value: widget.host,
            onChanged: (String newValue) async {
              widget.setHost(newValue);
              final prefs = await SharedPreferences.getInstance();
              prefs.setString("host", newValue);
            },
            items: Config.HOSTS
                .map<DropdownMenuItem<String>>((String value) {
                  return DropdownMenuItem<String>(
                    value: value,
                    child: Text(value),
                  );
                })
                .toList(),
            )
        )
      );
    }

    return Scaffold(
        body: SafeArea(
            child: SingleChildScrollView(
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.center,
                  crossAxisAlignment: CrossAxisAlignment.stretch,
                  children: children
                ))));
  }

  Widget wrapInContainer(Widget widget) {
    return Container(
      padding: EdgeInsets.all(10.0),
      child: widget,
    );
  }

  Widget _urlButton(BuildContext context, String title, listener) {
    return wrapInContainer(
        FlatButton(
          color: Theme.of(context).primaryColor,
          textColor: Colors.white,
          padding: const EdgeInsets.symmetric(horizontal: 50.0, vertical: 15.0),
          child: Text(title),
          onPressed: listener
        )
    );
  }
}